# Pypox

Convention based api framework built on top of FastAPI

**Documentation**: <a href="https://po-key.github.io/pypox" target="_blank">https://po-key.github.io/pypox</a>

**Source code**: <a href="https://github.com/Po-key/pypox" target="_blank">https://github.com/Po-key/pypox</a>

## Installation

1. Clone the repository:

   ```bash
   git clone https://github.com/Po-key/package-template.git
   ```

2. Navigate to the project directory:

   ```bash
   cd your-repository
   ```

3. Install dependencies using Poetry:
   ```bash
   poetry install
   ```

## Description

This is the base template for po-key system. feel free to use it at any time.

## License

This project is licensed under the MIT LICENSE - see the [LICENSE](LICENSE) file for details.
